@@ -253,7 +253,7 @@ KateGlobalConfig::KateGlobalConfig()
                                    return isEncodingOk(value.toString());
                                }));
 
-    // finalize the entries, e.g. hashs them
+    // finalize the entries, e.g. hashes them
     finalizeConfigEntries();
 
     // init with defaults from config or really hardcoded ones
@@ -366,7 +366,7 @@ KateDocumentConfig::KateDocumentConfig()
     // .editorconfig
     addConfigEntry(ConfigEntry(UseEditorConfig, "Use Editor Config", QString(), true));
 
-    // finalize the entries, e.g. hashs them
+    // finalize the entries, e.g. hashes them
     finalizeConfigEntries();
 
     // init with defaults from config or really hardcoded ones
@@ -572,6 +572,13 @@ KateViewConfig::KateViewConfig()
     addConfigEntry(ConfigEntry(EnableAccessibility, "Enable Accessibility", QString(), true));
     addConfigEntry(ConfigEntry(CycleThroughBookmarks, "Cycle Through Bookmarks", QString(), true));
 
+    // render line highlight and cursor just if focused
+    addConfigEntry(ConfigEntry(DisableCurrentLineHighlightIfInactive,
+                               "Disable current line highlight if inactive",
+                               QStringLiteral("disable-current-line-highlight-if-inactive"),
+                               false));
+    addConfigEntry(ConfigEntry(HideCursorIfInactive, "Hide cursor if inactive", QStringLiteral("hide-cursor-if-inactive"), false));
+
     // Never forget to finalize or the <CommandName> becomes not available
     finalizeConfigEntries();
 
